@@ -23,7 +23,7 @@
 #
 `is.timeBased` <- `timeBased` <-
 function(x) {
-if (!any(sapply(c("Date", "POSIXct", "chron", "dates", "times", 
+if (!any(sapply(c("Date", "POSIXt", "chron", "dates", "times", 
         "timeDate", "yearmon", "yearqtr", "xtime"), function(xx) inherits(x, 
         xx)))) {
         FALSE
